#!/usr/bin/python
# -*- coding: utf-8 -*-

# _Platform/Classic.py
#
# This file is part of BotMU
#
# Author: Raphaël Perraudeau <r.perraudeau@gmail.com>
# Copyright: 2011 Raphaël Perraudeau <r.perraudeau@gmail.com>
# Licence: GNU/GPL
#
# Home page: <http://botmu.sourceforge.net/>


import os
import sys
import datetime

from PyQt4.QtCore import *

from commonFunctions import *
from httpReq import *


#############################################################################
class Abort(Exception):
	"""classe d'exception crée pour l'arrêt du téléchargement avant la fin"""
	pass
 
#############################################################################
class Telecharger(QThread):
	"""Thread de téléchargement"""

	#========================================================================
	def __init__(self, fileList, destination, parent=None):
		super(Telecharger,self).__init__()
		self.destination = destination
		self.stop = False
		self.httpreq = httpReq(parent.configDir)
		self.fileRunning = ""
		self.downloadingFile = 0
		self.parent = parent
		self.fileList = fileList
		
		setupFile = os.path.join(self.parent.configDir, "setup.ini")
		paramfile = open(setupFile)
		param = (paramfile.read()).split("\n")
		for item in param:
			if item.split("=")[0] == 'proxy':
				self.proxy = item.split("=")[1]
				self.httpreq.defineProxy(self.proxy)
			if item.split("=")[0] == 'useragent':
				self.useragent = item.split("=")[1]
				self.httpreq.defineUseragent(self.useragent)
			if item.split("=")[0] == 'verbose':
				self.verbose = item.split("=")[1]
				self.httpreq.defineVerbose(int(self.verbose))
			if item.split("=")[0] == 'limit':
				self.limit = item.split("=")[1]
				self.httpreq.defineLimit(int(self.limit))

	#========================================================================
	def run(self):
		row = 0
		self.stop = False
		while self.fileList:
			if len(self.fileList)>row:
				LinkSrc = self.fileList[row][0]
				dest = self.fileList[row][1]
				continuedl = self.fileList[row][3]
				if(continuedl != 100):
					self.downloadingFile = row
					self.downloadFile(LinkSrc, dest, row, continuedl)
			else:
				break
			row+=1
	
	#http://www.megaupload.com/?d=AGI7OZ4M
	#========================================================================
	def downloadFile(self, LinkSrc, dest, row, continuedl=0):
		error = False
		fileDlEnd = False
		self.row = row
		try:
			LinkSrc = str(LinkSrc)
			dest = str(dest)
		except OSError, e:
			error = True
			messagefin = u"Erreur OS: function DownloadFile: %s" % e
			logError("_Platform - Classique - downloadFile - 1", sys.exc_info()[0], sys.exc_info()[1])
		except:
			logError("_Platform - Classique - downloadFile - 2", sys.exc_info()[0], sys.exc_info()[1])
		if not error:
			page = 0
			try:
				self.filename = dest
				self.msgInf = [u"Contact de %s..." % (LinkSrc), 1]
				self.infotelech(0, 0, 0)
				self.fileRunning = LinkSrc
				if self.filename == "auto":
					self.filename = self.httpreq.getPage(LinkSrc).geturl().split("/")[-1]
					self.infotelech(0, 0, 0)
				dest = os.path.join(self.destination, self.filename)
				self.msgInf = [u"Téléchargement de %s en cours" % (self.filename), 2]
				
				self.httpreq.defineContinue(continuedl)
				page = self.httpreq.getPage(LinkSrc, dest=dest, report_hook=self.infotelech)
				self.httpreq.defineContinue(0)

				self.fileRunning = ''
			
				if isInt(page):
					if page == -1:
						messagefin = u"Téléchargement stoppé"
					elif page == -2:
						messagefin = u"l'Url est invalide"
					elif page == -3:
						messagefin = u"Impossible de contacter l'url, verifier la disponibilité du lien"
					else:
						messagefin = u"Erreur sur %s : %s" % (page, sys.exc_info()[1])
						logError("_Platform - Classique - downloadFile - 3", sys.exc_info()[0], sys.exc_info()[1])
				elif self.stop == True:
					messagefin = u"Téléchargement stoppé"
				else:
					messagefin = u"Téléchargement terminé\n\n"
			except Abort:
				messagefin = u"Téléchargement stoppé"
			except:
				messagefin = u"l'Url est invalide ou pas de connexion internet"
				logError("_Platform - Classique - downloadFile - 3", sys.exc_info()[0], sys.exc_info()[1])
		if self.parent.appMethod == "gui":
			self.emit(SIGNAL("fintelech(PyQt_PyObject)"), [messagefin, row, "Classique"])
		else:
			self.parent.fintelech([messagefin, row, "Classique"])

	#========================================================================
	def infotelech(self, telechbloc, taillebloc, totalblocs):
		"""reçoit les infos de progression du téléchargement"""
		# nécessaire pour stopper le téléchargement avant la fin
		if self.stop:
			raise Abort
		# envoie les infos de progression à la fenêtre graphique
		if self.parent.appMethod == "gui":
			self.emit(SIGNAL("infotelech(PyQt_PyObject)"), [telechbloc, taillebloc, totalblocs, self.msgInf, self.row, self.filename, "Classique"])
		else:
			self.parent.infotelech([telechbloc, taillebloc, totalblocs, self.msgInf, self.row, self.filename, "Classique"])
		
 
	#========================================================================
	def stoptelech(self):
		# permet l'arrêt du téléchargement avant la fin
		self.stop = True
		
	#========================================================================
	def pausetelech(self):
		# permet la pause du téléchargement
		if self.httpreq.pause == True:
			self.httpreq.pause = False
		else:
			self.httpreq.pause = True
